@@ -18,32 +18,27 @@
 
 #include "novag.h"
 
-bool Game::add_move (int num, player_t player, cstr move)
-{
-	if (player == get_move_player() ||
-	    player == BLACK && num != get_move_num() ||
-	    player == WHITE && num != (get_move_num() + 1)) {
-		// this is not the move we were expecting
-		return false;
-	}
-	else {
-		positions.push_back (Position (pos(), move));
-		return true;
-	}
+bool Game::add_move(int num, player_t player, cstr move) {
+  if (player == get_move_player() || player == BLACK && num != get_move_num() ||
+      player == WHITE && num != (get_move_num() + 1)) {
+    // this is not the move we were expecting
+    return false;
+  }
+  else {
+    positions.push_back(Position(pos(), move));
+    return true;
+  }
 }
 
-void Game::add_move (cstr move)
-{
-	positions.push_back (Position (pos(), move));
+void Game::add_move(cstr move) {
+  positions.push_back(Position(pos(), move));
 }
 
-void Game::take_back ()
-{
-	positions.pop_back ();
+void Game::take_back() {
+  positions.pop_back();
 }
 
-void Game::reset ()
-{
-	positions.clear ();
-	positions.push_back (Position ());  // initial position
+void Game::reset() {
+  positions.clear();
+  positions.push_back(Position());  // initial position
 }
